AvahiHandler class abstract

Handles communication with the Avahi daemon.

Implementers

Constructors

AvahiHandler({required DBusClient busClient})
Creates a new Avahi handler instance.
const

Properties

busClient → DBusClient
The DBus client.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createAvahiRecordBrowser(AvahiBonsoirDiscovery discovery, BonsoirService service) → Future<AvahiRecordBrowser>
Creates a Avahi record browser for the given service.
getAvahiServiceBrowserPath(String serviceType) → Future<String>
Creates the Avahi service browser path.
initialize() → void
Initializes the handler.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveService(AvahiBonsoirDiscovery discovery, BonsoirService service, AvahiServiceBrowserItemNew event) → Future<void>
Resolves a service using its event.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited