AvahiEntryGroup class

Constructors

AvahiEntryGroup(DBusClient client, String destination, DBusObjectPath path)

Properties

client → DBusClient
The client this object is accessed from.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the client providing this object.
finalinherited
path → DBusObjectPath
The path to the object.
finalinherited
propertiesChanged ↔ Stream<DBusPropertiesChangedSignal>
Stream of signals when the remote object indicates a property has changed.
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateChanged ↔ Stream<AvahiEntryGroupStateChanged>
Stream of org.freedesktop.Avahi.EntryGroup.StateChanged signals.
latefinal

Methods

callAddAddress(int interface, int protocol, int flags, String name, String address, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<void>
Invokes org.freedesktop.Avahi.EntryGroup.AddAddress()
callAddRecord(int interface, int protocol, int flags, String name, int clazz, int type, int ttl, List<int> rdata, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<void>
Invokes org.freedesktop.Avahi.EntryGroup.AddRecord()
callAddService({required int interface, required int protocol, required int flags, required String name, required String type, required String domain, required String host, required int port, required List<List<int>> txt, bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<void>
Invokes org.freedesktop.Avahi.EntryGroup.AddService()
callAddServiceSubtype(int interface, int protocol, int flags, String name, String type, String domain, String subtype, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<void>
Invokes org.freedesktop.Avahi.EntryGroup.AddServiceSubtype()
callCommit({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<void>
Invokes org.freedesktop.Avahi.EntryGroup.Commit()
callFree({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<void>
Invokes org.freedesktop.Avahi.EntryGroup.Free()
callGetState({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<int>
Invokes org.freedesktop.Avahi.EntryGroup.GetState()
callIntrospect({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.DBus.Introspectable.Introspect()
callIsEmpty({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<bool>
Invokes org.freedesktop.Avahi.EntryGroup.IsEmpty()
callMethod(String? interface, String name, Iterable<DBusValue> values, {DBusSignature? replySignature, bool noReplyExpected = false, bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<DBusMethodSuccessResponse>
Invokes a method on this object. Throws DBusMethodResponseException if the remote side returns an error.
inherited
callReset({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<void>
Invokes org.freedesktop.Avahi.EntryGroup.Reset()
callUpdateServiceTxt(int interface, int protocol, int flags, String name, String type, String domain, List<List<int>> txt, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<void>
Invokes org.freedesktop.Avahi.EntryGroup.UpdateServiceTxt()
getAllProperties(String interface) → Future<Map<String, DBusValue>>
Gets the values of all the properties on this object.
inherited
getProperty(String interface, String name, {DBusSignature? signature}) → Future<DBusValue>
Gets a property on this object.
inherited
introspect() → Future<DBusIntrospectNode>
Gets the introspection data for this object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProperty(String interface, String name, DBusValue value) → Future<void>
Sets a property on this object.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited