AvahiRecordBrowserItemRemove class

Signal data for org.freedesktop.Avahi.RecordBrowser.ItemRemove.

Constructors

AvahiRecordBrowserItemRemove(DBusSignal signal)

Properties

clazz → int
no setter
flags → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
interface → String
Interface emitting the signal.
finalinherited
interfaceValue → int
no setter
name → String
Signal name;
finalinherited
path → DBusObjectPath
Path of the object emitting the signal.
finalinherited
protocol → int
no setter
rdata → List<int>
no setter
recordName → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String?
Client that sent the signal.
finalinherited
signature → DBusSignature
Signature of values.
no setterinherited
type → int
no setter
values → List<DBusValue>
Values associated with the signal.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited