AvahiServer class

Constructors

AvahiServer(DBusClient client, String destination, DBusObjectPath path)

Properties

client → DBusClient
The client this object is accessed from.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the client providing this object.
finalinherited
path → DBusObjectPath
The path to the object.
finalinherited
propertiesChanged ↔ Stream<DBusPropertiesChangedSignal>
Stream of signals when the remote object indicates a property has changed.
latefinalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateChanged ↔ Stream<AvahiServerStateChanged>
Stream of org.freedesktop.Avahi.Server.StateChanged signals.
latefinal

Methods

callAddressResolverNew(int interface, int protocol, String address, int flags, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.AddressResolverNew()
callDomainBrowserNew(int interface, int protocol, String domain, int btype, int flags, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.DomainBrowserNew()
callEntryGroupNew({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.EntryGroupNew()
callGetAlternativeHostName(String name, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.GetAlternativeHostName()
callGetAlternativeServiceName(String name, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.GetAlternativeServiceName()
callGetAPIVersion({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<int>
Invokes org.freedesktop.Avahi.Server.GetAPIVersion()
callGetDomainName({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.GetDomainName()
callGetHostName({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.GetHostName()
callGetHostNameFqdn({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.GetHostNameFqdn()
callGetLocalServiceCookie({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<int>
Invokes org.freedesktop.Avahi.Server.GetLocalServiceCookie()
callGetNetworkInterfaceIndexByName(String name, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<int>
Invokes org.freedesktop.Avahi.Server.GetNetworkInterfaceIndexByName()
callGetNetworkInterfaceNameByIndex(int index, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.GetNetworkInterfaceNameByIndex()
callGetState({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<int>
Invokes org.freedesktop.Avahi.Server.GetState()
callGetVersionString({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.GetVersionString()
callHostNameResolverNew({required int interface, required int protocol, required String name, required int answerProtocol, required int flags, bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.HostNameResolverNew()
callIntrospect({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.DBus.Introspectable.Introspect()
callIsNSSSupportAvailable({bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<bool>
Invokes org.freedesktop.Avahi.Server.IsNSSSupportAvailable()
callMethod(String? interface, String name, Iterable<DBusValue> values, {DBusSignature? replySignature, bool noReplyExpected = false, bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<DBusMethodSuccessResponse>
Invokes a method on this object. Throws DBusMethodResponseException if the remote side returns an error.
inherited
callRecordBrowserNew(int interface, int protocol, String name, int clazz, int type, int flags, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.RecordBrowserNew()
callResolveAddress(int interface, int protocol, String address, int flags, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<List<DBusValue>>
Invokes org.freedesktop.Avahi.Server.ResolveAddress()
callResolveHostName(int interface, int protocol, String name, int aprotocol, int flags, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<List<DBusValue>>
Invokes org.freedesktop.Avahi.Server.ResolveHostName()
callResolveService({required int interface, required int protocol, required String name, required String type, required String domain, required int answerProtocol, required int flags, bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<List<DBusValue>>
Invokes org.freedesktop.Avahi.Server.ResolveService()
callServiceBrowserNew({required int interface, required int protocol, required String type, required String domain, required int flags, bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.ServiceBrowserNew()
callServiceResolverNew({required int interface, required int protocol, required String name, required String type, required String domain, required int aprotocol, required int flags, bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.ServiceResolverNew()
callServiceTypeBrowserNew(int interface, int protocol, String domain, int flags, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<String>
Invokes org.freedesktop.Avahi.Server.ServiceTypeBrowserNew()
callSetHostName(String name, {bool noAutoStart = false, bool allowInteractiveAuthorization = false}) → Future<void>
Invokes org.freedesktop.Avahi.Server.SetHostName()
getAllProperties(String interface) → Future<Map<String, DBusValue>>
Gets the values of all the properties on this object.
inherited
getProperty(String interface, String name, {DBusSignature? signature}) → Future<DBusValue>
Gets a property on this object.
inherited
introspect() → Future<DBusIntrospectNode>
Gets the introspection data for this object.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setProperty(String interface, String name, DBusValue value) → Future<void>
Sets a property on this object.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited