AvahiServerResolvedService class

Return value of org.freedesktop.Avahi.Server.ResolveService.

Constructors

AvahiServerResolvedService(Iterable<DBusValue> children)

Properties

address → String
no setter
aprotocol → AvahiProtocol?
no setter
children → List<DBusValue>
Child values in this structure.
finalinherited
domain → String
no setter
flags → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
host → String
no setter
interface → int
no setter
name → String
no setter
port → int
no setter
protocol → AvahiProtocol?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature → DBusSignature
Gets the signature for this value.
no setterinherited
txt → List<String>
no setter
type → String
no setter
values → List<DBusValue>
final

Methods

asArray() → List<DBusValue>
Extracts the array inside this value. Only works if signature is an array type, e.g 'as'.
inherited
asBoolean() → bool
Converts this value to the native Dart representation of a boolean. Only works if signature is 'b'.
inherited
asBooleanArray() → Iterable<bool>
Extracts the boolean values inside this array. Only works if signature is 'ab'.
inherited
asByte() → int
Converts this value to the native Dart representation of a byte. Only works if signature is 'y'.
inherited
asByteArray() → Iterable<int>
Extracts the bytes inside this array. Only works if signature is 'ay'.
inherited
asDict() → Map<DBusValue, DBusValue>
Extracts the dictionary inside this vlaue. Only works if signature is a dictionary type, e.g 'a{os}'.
inherited
asDouble() → double
Converts this value to the native Dart representation of a 64 bit floating point number. Only works if signature is 'd'.
inherited
asDoubleArray() → Iterable<double>
Extracts the 64 bit floating point numbers inside this array. Only works if signature is 'ad'.
inherited
asInt16() → int
Converts this value to the native Dart representation of a 16 bit signed integer. Only works if signature is 'n'.
inherited
asInt16Array() → Iterable<int>
Extracts the 16 bit signed integers inside this array. Only works if signature is 'an'.
inherited
asInt32() → int
Converts this value to the native Dart representation of a 32 bit signed integer. Only works if signature is 'i'.
inherited
asInt32Array() → Iterable<int>
Extracts the 32 bit signed integers inside this array. Only works if signature is 'ai'.
inherited
asInt64() → int
Converts this value to the native Dart representation of a 64 bit signed integer. Only works if signature is 'x'.
inherited
asInt64Array() → Iterable<int>
Extracts the 64 bit signed integers inside this array. Only works if signature is 'ax'.
inherited
asMaybe() → DBusValue?
Extracts the maybe type inside this value. Only works if signature is a maybe type, e.g. 'mi'.
inherited
asObjectPath() → DBusObjectPath
Extracts the object path inside this value. Only works if signature is 'o'.
inherited
asObjectPathArray() → Iterable<DBusObjectPath>
Extracts the object paths inside this array. Only works if signature is 'ao'.
inherited
asSignature() → DBusSignature
Extracts the signature inside this value. Only works if signature is 'g'.
inherited
asSignatureArray() → Iterable<DBusSignature>
Extracts the signatures inside this array. Only works if signature is 'ag'.
inherited
asString() → String
Converts this value to the native Dart representation of a string. Only works if signature is 's'.
inherited
asStringArray() → Iterable<String>
Extracts the strings inside this array. Only works if signature is 'as'.
inherited
asStringVariantDict() → Map<String, DBusValue>
Extracts the string to variant dictionary inside this value. Only works if signature is 'a{sv}'.
inherited
asStruct() → List<DBusValue>
Extracts this child values inside this struct. Only works if signature is a struct type, e.g '(si)'.
inherited
asUint16() → int
Converts this value to the native Dart representation of a 16 bit unsigned integer. Only works if signature is 'q'.
inherited
asUint16Array() → Iterable<int>
Extracts the 16 bit unsigned integers inside this array. Only works if signature is 'aq'.
inherited
asUint32() → int
Converts this value to the native Dart representation of a 32 bit unsigned integer. Only works if signature is 'u'.
inherited
asUint32Array() → Iterable<int>
Extracts the 32 bit unsigned integers inside this array. Only works if signature is 'au'.
inherited
asUint64() → int
Converts this value to the native Dart representation of a 64 bit unsigned integer. Only works if signature is 't'.
inherited
asUint64Array() → Iterable<int>
Extracts the 64 bit unsigned integers inside this array. Only works if signature is 'at'.
inherited
asUnixFd() → ResourceHandle
Extracts the ResourceHandle inside this unix file descriptor D-Bus value. Only works if signature is 'h'.
inherited
asUnixFdArray() → Iterable<ResourceHandle>
Extracts the resource handles inside this array of unix file descriptors. Only works if signature is 'ah'.
inherited
asVariant() → DBusValue
Extracts the value stored inside this variant. Only works if signature is 'v'.
inherited
asVariantArray() → Iterable<DBusValue>
Extracts the values inside this variant array. Only works if signature is 'av'.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNative() → dynamic
Converts this value to a native Dart representation.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited