AvahiServiceResolverFound class

Signal data for org.freedesktop.Avahi.ServiceResolver.Found.

Constructors

AvahiServiceResolverFound(DBusSignal signal)

Properties

address → String
no setter
aprotocol → int
no setter
domain → String
no setter
flags → int
no setter
hashCode → int
The hash code for this object.
no setterinherited
host → String
no setter
interface → String
Interface emitting the signal.
finalinherited
interfaceValue → int
no setter
name → String
Signal name;
finalinherited
path → DBusObjectPath
Path of the object emitting the signal.
finalinherited
port → int
no setter
protocol → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender → String?
Client that sent the signal.
finalinherited
serviceName → String
no setter
signature → DBusSignature
Signature of values.
no setterinherited
txt → List<String>
no setter
type → String
no setter
values → List<DBusValue>
Values associated with the signal.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited