AvahiBonsoirError class

Represents a Bonsoir error triggered on the Linux platform.

Implemented types

Constructors

AvahiBonsoirError(String message, [Object? error])
Creates a new Avahi Bonsoir error instance.

Properties

error → Object?
The (possibly null) error code / message.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
The message.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited